@@ -4,13 +4,13 @@
     Describe Kafka topics
 """
 
-from confluent_kafka.admin import AdminClient, ConfigResource, ConfigSource
-from confluent_kafka import KafkaException
-
-import os
 import json
+import os
 import pkgutil
 
+from confluent_kafka import KafkaException
+from confluent_kafka.admin import AdminClient, ConfigResource
+
 
 def describe_topics() -> None:
     """
@@ -18,35 +18,32 @@ def describe_topics() -> None:
     """
     bootstrap_servers = os.environ.get('BOOTSTRAP_SERVERS', 'localhost:9092')
 
-    a = AdminClient({'bootstrap.servers': bootstrap_servers})
+    admin_client = AdminClient({'bootstrap.servers': bootstrap_servers})
 
     conf = pkgutil.get_data("jaws_libp", "avro/topics.json")
 
     topics = json.loads(conf)
 
     def print_config(config, depth):
-        print('%40s = %-50s' %
-              ((' ' * depth) + config.name, config.value))
+        print(f'{(" " * depth) + config.name:>40} = {config.value:<50}')
 
     resources = []
 
-    for t in topics:
-        resources.append(ConfigResource('topic', t))
+    for topic in topics:
+        resources.append(ConfigResource('topic', topic))
 
-    fs = a.describe_configs(resources)
+    futures = admin_client.describe_configs(resources)
 
-    for res, f in fs.items():
+    for res, future in futures.items():
         try:
-            configs = f.result()
+            configs = future.result()
             print("")
-            print("Topic {}".format(res.name))
+            print(f"Topic {res.name}")
             print("-----------------------------------------------------------------")
             for config in iter(configs.values()):
                 print_config(config, 1)
         except KafkaException as e:
-            print("Failed to describe {}: {}".format(res, e))
-        except Exception:
-            raise
+            print(f"Failed to describe {res}: {e}")
 
 
 if __name__ == "__main__":
