@@ -9,14 +9,23 @@ import click
 from jaws_libp.clients import InstanceConsumer
 
 
+# pylint: disable=too-few-public-methods
 class ClassFilter:
+    """
+        Filter class messages
+    """
     def __init__(self, alarm_class):
         self._alarm_class = alarm_class
 
+    # pylint: disable=unused-argument
     def filter_if(self, key, value):
+        """
+            Filter out messages unless the class name matches the provided class name
+        """
         return self._alarm_class is None or (value is not None and self._alarm_class == value.alarm_class)
 
 
+# pylint: disable=missing-function-docstring,no-value-for-parameter
 @click.command()
 @click.option('--monitor', is_flag=True, help="Monitor indefinitely")
 @click.option('--nometa', is_flag=True, help="Exclude audit headers and timestamp")
@@ -36,4 +45,3 @@ def click_main() -> None:
 
 if __name__ == "__main__":
     click_main()
-
