@@ -14,12 +14,14 @@ from jaws_libp.clients import LocationConsumer, InstanceProducer
 from jaws_libp.entities import AlarmInstance, \
     SimpleProducer, EPICSProducer, CALCProducer
 
+LOCATIONS = []
 
 if __name__ == "__main__":
     consumer = LocationConsumer('set_instance.py')
-    locations = consumer.get_keys_then_done()
+    LOCATIONS = consumer.get_keys_then_done()
 
 
+# pylint: disable=duplicate-code,missing-function-docstring,too-many-arguments,no-value-for-parameter
 @click.command()
 @click.option('--file', is_flag=True,
               help="Imports a file of key=value pairs (one per line) where the key is alarm name and value is JSON "
@@ -29,14 +31,14 @@ if __name__ == "__main__":
 @click.option('--producersimple', is_flag=True, help="Simple alarm (producer)")
 @click.option('--producerpv', help="The name of the EPICS CA PV that directly powers this alarm")
 @click.option('--producerexpression', help="The CALC expression used to generate this alarm")
-@click.option('--location', '-l', type=click.Choice(locations), multiple=True,
+@click.option('--location', '-l', type=click.Choice(LOCATIONS), multiple=True,
               help="The alarm location (Options queried on-demand from alarm-locations topic).  Multiple locations "
                    "allowed.")
 @click.option('--screencommand', help="The command to open the related control system screen")
 @click.option('--maskedby', help="The optional parent alarm that masks this one")
 @click.argument('name')
 def set_instance(file, unset, alarmclass, producersimple, producerpv, producerexpression, location,
-        screencommand, maskedby, name) -> None:
+                 screencommand, maskedby, name) -> None:
     producer = InstanceProducer('set_instance.py')
 
     key = name
@@ -52,17 +54,17 @@ def set_instance(file, unset, alarmclass, producersimple, producerpv, producerex
                     "Must specify one of --producersimple, --producerpv, --producerexpression")
 
             if producersimple:
-                p = SimpleProducer()
+                source_producer = SimpleProducer()
             elif producerpv:
-                p = EPICSProducer(producerpv)
+                source_producer = EPICSProducer(producerpv)
             else:
-                p = CALCProducer(producerexpression)
+                source_producer = CALCProducer(producerexpression)
 
             if alarmclass is None:
                 alarmclass = "base"
 
             value = AlarmInstance(alarmclass,
-                                  p,
+                                  source_producer,
                                   location,
                                   maskedby,
                                   screencommand)
@@ -76,4 +78,3 @@ def click_main() -> None:
 
 if __name__ == "__main__":
     click_main()
-
